@@ -45,7 +45,9 @@ func useDynamicCommands(app *cli.App) {
 		path, err := exec.LookPath(pluginName)
 		if err == nil {
 			os.Args = append([]string{pluginName}, os.Args[2:]...)
-			_ = executePlugin(ctx, path, os.Args, os.Environ())
+			if err := executePlugin(ctx, path, os.Args, os.Environ()); err != nil {
+				fmt.Fprintf(os.Stderr, "unable to complete plugin execution\n%s\n", err)
+			}
 		}
 
 		fmt.Fprintf(os.Stderr, "%s is not a command. See '%s --help\n'", cmdToFind, ctx.App.Name)
