@@ -27,13 +27,13 @@ package cli_curr
 import (
 	"fmt"
 
-	"github.com/temporalio/tctl/v2/config"
+	"github.com/temporalio/tctl/config"
 	"github.com/urfave/cli"
 
-	"github.com/temporalio/tctl/v2/cli/headers"
-	"github.com/temporalio/tctl/v2/cli_curr/dataconverter"
-	"github.com/temporalio/tctl/v2/cli_curr/headersprovider"
-	"github.com/temporalio/tctl/v2/cli_curr/plugin"
+	"github.com/temporalio/tctl/cli/headers"
+	"github.com/temporalio/tctl/cli_curr/dataconverter"
+	"github.com/temporalio/tctl/cli_curr/headersprovider"
+	"github.com/temporalio/tctl/cli_curr/plugin"
 )
 
 // SetFactory is used to set the ClientFactory global
@@ -155,6 +155,11 @@ func NewCliApp() *cli.App {
 			Usage:       "Operate Temporal task queue",
 			Subcommands: newTaskQueueCommands(),
 		},
+		{
+			Name:        "schedule",
+			Usage:       "Operate schedules",
+			Subcommands: newScheduleCommands(),
+		},
 		{
 			Name:        "batch",
 			Usage:       "Batch operation on a list of workflows from query",
