@@ -47,9 +47,9 @@ import (
 	sdkclient "go.temporal.io/sdk/client"
 	"go.temporal.io/sdk/converter"
 
-	"github.com/temporalio/tctl/v2/cli/headers"
-	"github.com/temporalio/tctl/v2/cli_curr/dataconverter"
-	"github.com/temporalio/tctl/v2/cli_curr/stringify"
+	"github.com/temporalio/tctl/cli/headers"
+	"github.com/temporalio/tctl/cli_curr/dataconverter"
+	"github.com/temporalio/tctl/cli_curr/stringify"
 	"go.temporal.io/server/common/codec"
 	"go.temporal.io/server/common/collection"
 	"go.temporal.io/server/common/payloads"
@@ -81,12 +81,13 @@ func HistoryEventToString(e *historypb.HistoryEvent, printFully bool, maxFieldLe
 
 // ColorEvent takes an event and return string with color
 // Event with color mapping rules:
-//   Failed - red
-//   Timeout - yellow
-//   Canceled - magenta
-//   Completed - green
-//   Started - blue
-//   Others - default (white/black)
+//
+//	Failed - red
+//	Timeout - yellow
+//	Canceled - magenta
+//	Completed - green
+//	Started - blue
+//	Others - default (white/black)
 func ColorEvent(e *historypb.HistoryEvent) string {
 	var data string
 	switch e.GetEventType() {
@@ -827,3 +828,41 @@ func defaultDataConverter() converter.DataConverter {
 func customDataConverter() converter.DataConverter {
 	return dataconverter.GetCurrent()
 }
+
+func encodeMemo(memo map[string]interface{}) *commonpb.Memo {
+	if len(memo) == 0 {
+		return nil
+	}
+	dc := customDataConverter()
+	fields := make(map[string]*commonpb.Payload, len(memo))
+	var err error
+	for k, v := range memo {
+		fields[k], err = dc.ToPayload(v)
+		if err != nil {
+			ErrorAndExit("unable to encode memo", err)
+		}
+	}
+	return &commonpb.Memo{Fields: fields}
+}
+
+func encodeSearchAttributes(sa map[string]interface{}) *commonpb.SearchAttributes {
+	if len(sa) == 0 {
+		return nil
+	}
+	dc := defaultDataConverter()
+	fields := make(map[string]*commonpb.Payload, len(sa))
+	var err error
+	for k, v := range sa {
+		fields[k], err = dc.ToPayload(v)
+		if err != nil {
+			ErrorAndExit("unable to encode search attributes", err)
+		}
+	}
+	return &commonpb.SearchAttributes{IndexedFields: fields}
+}
+
+func ensureNonNil[T any, P ~*T](ptr *P) {
+	if *ptr == nil {
+		*ptr = new(T)
+	}
+}
